pub enum SideType {
Required,
Optional,
Unsupported,
Unknown,
}Variants
Required
The mod is required on this side to function
Optional
The mod is not required on this side to function. However, functionality might be enhanced if it is present.
Unsupported
The mod will not run on this side
Unknown
It is unknown if the project will run on this side