pub struct VersionFile {
pub hashes: Hash,
pub url: Url,
pub filename: String,
pub primary: bool,
pub size: Int,
pub file_type: Option<AdditionalFileType>,
}Fields
hashes: Hashurl: Urlfilename: Stringprimary: boolWhether the file is the primary file of its version
There can only be a maximum of one primary file per version. If there are no primary files specified, the first file can be taken as the primary one.
size: IntThe size of the file in bytes
file_type: Option<AdditionalFileType>The type of the additional file, used mainly for adding resource packs to datapacks